@@ -1,17 +1,17 @@
 package Digest::SHA;
 
-require 5.006000;
+require 5.003000;
 
 use strict;
-use warnings;
 use integer;
+use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
-our $VERSION = '5.41';
+$VERSION = '5.46';
 
 require Exporter;
-our @ISA = qw(Exporter);
-
-our @EXPORT_OK = qw(
+require DynaLoader;
+@ISA = qw(Exporter DynaLoader);
+@EXPORT_OK = qw(
 	hmac_sha1	hmac_sha1_base64	hmac_sha1_hex
 	hmac_sha224	hmac_sha224_base64	hmac_sha224_hex
 	hmac_sha256	hmac_sha256_base64	hmac_sha256_hex
@@ -37,11 +37,6 @@ if ($@) {
 	*b64digest = \&B64digest;
 }
 
-require XSLoader;
-XSLoader::load('Digest::SHA', $VERSION);
-
-# Preloaded methods go here.
-
 # The following routines aren't time-critical, so they can be left in Perl
 
 sub new {
@@ -118,32 +113,35 @@ sub Addfile {
 	my ($binary, $portable) = map { $_ eq $mode } ("b", "p");
 	my $text = -T $file;
 
-	local *F;
-	_bail("Open failed") unless open(F, "<$file");
-	binmode(F) if $binary || $portable;
+	local *FH;
+		# protect any leading or trailing whitespace in $file;
+		# otherwise, 2-arg "open" will ignore them
+	$file =~ s#^(\s)#./$1#;
+	open(FH, "< $file\0") or _bail("Open failed");
+	binmode(FH) if $binary || $portable;
 
 	unless ($portable && $text) {
-		$self->_addfile(*F);
-		close(F);
+		$self->_addfile(*FH);
+		close(FH);
 		return($self);
 	}
 
 	my ($n1, $n2);
 	my ($buf1, $buf2) = ("", "");
 
-	while (($n1 = read(F, $buf1, 4096))) {
+	while (($n1 = read(FH, $buf1, 4096))) {
 		while (substr($buf1, -1) eq "\015") {
-			$n2 = read(F, $buf2, 4096);
+			$n2 = read(FH, $buf2, 4096);
 			_bail("Read failed") unless defined $n2;
 			last unless $n2;
 			$buf1 .= $buf2;
 		}
 		$buf1 =~ s/\015?\015\012/\012/g; 	# DOS/Windows
-		$buf1 =~ s/\015/\012/g;          	# Apple/MacOS 9
+		$buf1 =~ s/\015/\012/g;          	# early MacOS
 		$self->add($buf1);
 	}
 	_bail("Read failed") unless defined $n1;
-	close(F);
+	close(FH);
 
 	$self;
 }
@@ -170,6 +168,8 @@ sub load {
 	return($self);
 }
 
+Digest::SHA->bootstrap($VERSION);
+
 1;
 __END__
 
@@ -177,7 +177,7 @@ __END__
 
 Digest::SHA - Perl extension for SHA-1/224/256/384/512
 
-=head1 SYNOPSIS (SHA)
+=head1 SYNOPSIS
 
 In programs:
 
@@ -323,6 +323,29 @@ the larger and stronger hash functions.>
 
 ref. L<http://www.csrc.nist.gov/pki/HashWorkshop/NIST%20Statement/Burr_Mar2005.html>
 
+=head1 PADDING OF BASE64 DIGESTS
+
+By convention, CPAN Digest modules do B<not> pad their Base64 output.
+Problems can occur when feeding such digests to other software that
+expects properly padded Base64 encodings.
+
+For the time being, any necessary padding must be done by the user.
+Fortunately, this is a simple operation: if the length of a Base64-encoded
+digest isn't a multiple of 4, simply append "=" characters to the end
+of the digest until it is:
+
+	while (length($b64_digest) % 4) {
+		$b64_digest .= '=';
+	}
+
+To illustrate, I<sha256_base64("abc")> is computed to be
+
+	ungWv48Bz+pBQUDeXa4iI7ADYaOWF3qctBD/YfIAFa0
+
+which has a length of 43.  So, the properly padded version is
+
+	ungWv48Bz+pBQUDeXa4iI7ADYaOWF3qctBD/YfIAFa0=
+
 =head1 EXPORT
 
 None by default.
@@ -378,6 +401,11 @@ its SHA-1/224/256/384/512 digest encoded as a hexadecimal string.
 Logically joins the arguments into a single string, and returns
 its SHA-1/224/256/384/512 digest encoded as a Base64 string.
 
+It's important to note that the resulting string does B<not> contain
+the padding characters typical of Base64 encodings.  This omission is
+deliberate, and is done to maintain compatibility with the family of
+CPAN Digest modules.  See L</"PADDING OF BASE64 DIGESTS"> for details.
+
 =back
 
 I<OOP style>
@@ -527,6 +555,11 @@ the original digest state.
 This method is inherited if L<Digest::base> is installed on your
 system.  Otherwise, a functionally equivalent substitute is used.
 
+It's important to note that the resulting string does B<not> contain
+the padding characters typical of Base64 encodings.  This omission is
+deliberate, and is done to maintain compatibility with the family of
+CPAN Digest modules.  See L</"PADDING OF BASE64 DIGESTS"> for details.
+
 =back
 
 I<HMAC-SHA-1/224/256/384/512>
@@ -578,6 +611,11 @@ with the result encoded as a Base64 string.  Multiple I<$data>
 arguments are allowed, provided that I<$key> is the last argument
 in the list.
 
+It's important to note that the resulting string does B<not> contain
+the padding characters typical of Base64 encodings.  This omission is
+deliberate, and is done to maintain compatibility with the family of
+CPAN Digest modules.  See L</"PADDING OF BASE64 DIGESTS"> for details.
+
 =back
 
 =head1 SEE ALSO
@@ -602,6 +640,7 @@ The author is particularly grateful to
 
 	Gisle Aas
 	Chris Carey
+	Jim Doble
 	Julius Duque
 	Jeffrey Friedl
 	Robert Gilmour
@@ -619,7 +658,7 @@ for their valuable comments and suggestions.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2006 Mark Shelor
+Copyright (C) 2003-2008 Mark Shelor
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
